import * as cdk from 'aws-cdk-lib';
import * as constructs from 'constructs';
/**
 * Adds a group as a member of another GitLab group
 *
 * @schema CfnGroupAccessToGroupProps
 */
export interface CfnGroupAccessToGroupProps {
    /**
     * ID of the group which should be shared, i.e. the group to which access is being granted
     *
     * @schema CfnGroupAccessToGroupProps#SharedGroupId
     */
    readonly sharedGroupId: number;
    /**
     * ID of the group to share with, i.e. the group being given access to another group
     *
     * @schema CfnGroupAccessToGroupProps#SharedWithGroupId
     */
    readonly sharedWithGroupId: number;
    /**
     * The access level to grant to the shared-with group for acessing the shared group, e.g. 'Guest', 'Developer', or 'Maintainer'. Note the GitLab API may not allow all values.
     *
     * @schema CfnGroupAccessToGroupProps#AccessLevel
     */
    readonly accessLevel: CfnGroupAccessToGroupPropsAccessLevel;
}
/**
 * Converts an object of type 'CfnGroupAccessToGroupProps' to JSON representation.
 */
export declare function toJson_CfnGroupAccessToGroupProps(obj: CfnGroupAccessToGroupProps | undefined): Record<string, any> | undefined;
/**
 * The access level to grant to the shared-with group for acessing the shared group, e.g. 'Guest', 'Developer', or 'Maintainer'. Note the GitLab API may not allow all values.
 *
 * @schema CfnGroupAccessToGroupPropsAccessLevel
 */
export declare enum CfnGroupAccessToGroupPropsAccessLevel {
    /** None */
    NONE = "None",
    /** Minimal Access */
    MINIMAL_ACCESS = "Minimal Access",
    /** Guest */
    GUEST = "Guest",
    /** Reporter */
    REPORTER = "Reporter",
    /** Developer */
    DEVELOPER = "Developer",
    /** Maintainer */
    MAINTAINER = "Maintainer",
    /** Owner */
    OWNER = "Owner",
    /** Admin */
    ADMIN = "Admin"
}
/**
 * A CloudFormation `GitLab::Groups::GroupAccessToGroup`
 *
 * @cloudformationResource GitLab::Groups::GroupAccessToGroup
 * @stability external
 * @link https://github.com/aws-ia/cloudformation-gitlab-resource-providers.git
 */
export declare class CfnGroupAccessToGroup extends cdk.CfnResource {
    /**
    * The CloudFormation resource type name for this resource class.
    */
    static readonly CFN_RESOURCE_TYPE_NAME = "GitLab::Groups::GroupAccessToGroup";
    /**
     * Resource props.
     */
    readonly props: CfnGroupAccessToGroupProps;
    /**
     * Attribute `GitLab::Groups::GroupAccessToGroup.MembershipId`
     * @link https://github.com/aws-ia/cloudformation-gitlab-resource-providers.git
     */
    readonly attrMembershipId: string;
    /**
     * Create a new `GitLab::Groups::GroupAccessToGroup`.
     *
     * @param scope - scope in which this resource is defined
     * @param id    - scoped id of the resource
     * @param props - resource properties
     */
    constructor(scope: constructs.Construct, id: string, props: CfnGroupAccessToGroupProps);
}
